###### This file replicates the analysis of happiness, age and income published in 
###### Toshkov (2021) 'The Relationship Between Age and Happiness Varies by Income', Journal of Happiness Studies
###### Part 1 of 6 (Data preparation). Last updated 1 September 2021

# Libraries and functions -------------------------------------------------
library(essurvey) # to access ESS data
library(labelled) 
library(tidyverse)
library(countrycode)
#set_email("xxx@xxx.com") # set your registered email

# Import the data and recode variables ------------------------------------
dat9 <- import_rounds(9, format = 'spss') # ESS Round 9, 2018. Can also be downloaded from the ESS website and imported

dat9 <- dat9 %>% 
  mutate (country = factor(countrycode (cntry, origin='iso2c', destination = 'country.name')),
          feel.happy = as.numeric(happy),
          life.satisfaction = as.numeric(stflife),
          edu = as.numeric(eisced),
          edu = ifelse (edu == 55, NA, edu),
          income = hinctnta,
          income.na = ifelse(is.na(income)==TRUE, 1, 0),
          income.f = factor (income),
          income.cat = ifelse(income < 3, 'Income deciles 1 and 2',ifelse(income > 8, 'Income deciles 9 and 10', 'Income deciles 3-7')),
          income.cat2 = ifelse(income < 4, 'Income deciles 1-3',ifelse(income > 7, 'Income deciles 8-10', NA)),
          income.cat3 = ifelse(income < 4, 'Income deciles 1-3', ifelse(income > 7, 'Income deciles 8-10', ifelse(is.na(income)==F , 'Income deciles 4-7', NA))),
          age = agea,
          age.cat = cut (age, breaks = c(-Inf, 20,30,40,50,60,70,80,Inf), labels = c('15-20','21-30','31-40','41-50','51-60','61-70','71-80','80+')), 
          relig = rlgdgr, 
          internet = netusoft,
          sex = ifelse(gndr==1, 'male' ,'female'),
          native = ifelse(brncntr==1, 'yes' ,'no'),
          empl = case_when (mnactic==1 ~ 'paid work',
                             mnactic==2   ~ 'studying',
                             mnactic==3 | mnactic==4    ~ 'unemployed',
                             mnactic==5 ~ 'disabled',
                             mnactic==6 ~ 'retired',
                             mnactic==8  ~ 'housework',
                             mnactic==9  ~ 'other'),
          social.trust = as.numeric(ppltrst), # trust in people
          feel.unsafe = as.numeric(aesfdrk), # feeling safe, 1 is safe 
          feel.unhealthy = as.numeric(health), # fee1ing healthy, 1 is healthy 
          feel.country.attached = as.numeric(atchctr), # feeling attached to country
          justice.prevails = 6 - as.numeric(jstprev),  #justice eventually prevails [needs to be inverted, originally 5 is disagree]
          diff.size = case_when (wltdffr==0 ~ 'fair',  # are differences in wealth in [country] unfairly small, fair, or unfairly large? [more is unfair]
                                  wltdffr < 0 ~ 'small',
                                  wltdffr > 0 ~ 'large'),
          diff.fair = case_when (wltdffr==0 ~ 'fair',  # are differences in wealth in [country] unfairly small, fair, or unfairly large? [more is unfair]
                                 wltdffr==-4 |  wltdffr==4 | wltdffr==-2 |  wltdffr==3  ~ 'very unfair',
                                 wltdffr==-2 |  wltdffr==2 | wltdffr==-1 |  wltdffr==1  ~ 'slightly unfair'),
          ppl.deserve = 6 - ppldsrv, # By and large, people get what they deserve (orignally 1 Agree to 5, inverted!),
          plan = 10- plnftr, #Do you generally plan for your future or do you just take each day as it comes? Original 0 (plan) to 10 (take days as they come)/ Inverted!
          married = case_when (maritalb==1 | maritalb==2 ~ 'married',
                               maritalb==3 | maritalb==4 ~ 'divorced',
                               maritalb==5  ~ 'widiwed',
                               maritalb==6  ~ 'alone'),
          grandchildren = ifelse (ggchld ==1, 'yes', 'no'),
          children = ifelse (bthcld ==1, 'yes', 'no'),
          lives.alone = ifelse (hhmmb==1, 'yes', 'no'),
          lives.parents = case_when (hhmmb>1 & (rshipa2 == 3 | rshipa2 == 4) ~ 'yes',
                                     TRUE ~ 'no')
    )

# Create Equivalised Income by taking into account number of persons in a household --------
dat9 <- dat9 %>% 
  mutate (income.cor = case_when(income==2 & hhmmb > 1 ~ 1,
                                 income==3 & hhmmb > 2 ~ 1,
                                 income==3 & hhmmb == 2 ~ 2,
                                 income==4 & hhmmb > 3 ~ 1,
                                 income==4 & hhmmb > 1 ~ 2,
                                 income==5 & hhmmb > 3 ~ 1,
                                 income==5 & hhmmb == 3 ~ 2,
                                 income==5 & hhmmb == 2 ~ 3,
                                 income==6 & hhmmb > 5 ~ 1,
                                 income==6 & hhmmb == 5 ~ 2,
                                 income==6 & hhmmb == 4 ~ 2,
                                 income==6 & hhmmb == 3 ~ 3,
                                 income==6 & hhmmb == 2 ~ 4,
                                 income==7 & hhmmb > 6 ~ 1,
                                 income==7 & hhmmb == 6 ~ 2,
                                 income==7 & hhmmb == 5 ~ 2,
                                 income==7 & hhmmb == 4 ~ 3,
                                 income==7 & hhmmb == 3 ~ 4,
                                 income==7 & hhmmb == 2 ~ 5,
                                 income==8 & hhmmb > 7 ~ 1,
                                 income==8 & hhmmb == 7 ~ 2,
                                 income==8 & hhmmb == 6 ~ 2,
                                 income==8 & hhmmb == 5 ~ 3,
                                 income==8 & hhmmb == 4 ~ 4,
                                 income==8 & hhmmb == 3 ~ 5,
                                 income==8 & hhmmb == 2 ~ 6,
                                 income==8 & hhmmb > 7 ~ 1,
                                 income==9 & hhmmb == 7 ~ 2,
                                 income==9 & hhmmb == 6 ~ 3,
                                 income==9 & hhmmb == 5 ~ 4,
                                 income==9 & hhmmb == 4 ~ 5,
                                 income==9 & hhmmb == 3 ~ 6,
                                 income==9 & hhmmb == 2 ~ 7,
                                 income==10 & hhmmb > 7 ~ 5,
                                 income==10 & hhmmb == 7 ~ 6,
                                 income==10 & hhmmb == 6 ~ 6,
                                 income==10 & hhmmb == 5 ~ 7,
                                 income==10 & hhmmb == 4 ~ 8,
                                 income==10 & hhmmb == 3 ~ 9,
                                 TRUE ~ as.numeric(as.character(income))))




# Get country means and reorder factors -----------------------------------
means<-dat9 %>%
  group_by(cntry) %>%
  summarise (means = round(mean(happy, na.rm=T),2)) %>%
  ungroup() %>%
  data.frame()

dat9 <- left_join (dat9, means, by='cntry')
dat9$country <- fct_reorder(dat9$country, dat9$means, mean, na.rm=TRUE, .desc = TRUE)

levels(dat9$income.f) <- paste0('Income decile: ',1:10)
# Some simple descriptive stats -------------------------------------------
mean (dat9$happy, na.rm=TRUE)
sd (dat9$happy, na.rm=TRUE)
median (dat9$happy, na.rm=TRUE)

mean(dat9$age, na.rm=TRUE)
median(dat9$age, na.rm=TRUE)
sd(dat9$age, na.rm=TRUE)
round(prop.table(table(dat9$income))*100,1)

# Simple models of missing incomes ----------------------------------------
summary(glm(income.na ~ edu + empl,family='binomial', data=dat9))
summary(glm(income.na ~ edu + empl + age + social.trust + feel.unsafe,family='binomial', data=dat9))

# End of part 1 of 6
