###### This file replicates the analysis of happiness, age and income published in 
###### Toshkov (2021) 'The Relationship Between Age and Happiness Varies by Income', Journal of Happiness Studies
###### Part 2 of 6 (Preparing the figures). Last updated 1 September 2021

# Load the common graphical settings --------------------------------------
source ('ggplot2 graphical settings.R')
library(patchwork)
# Figure 1: Unadjusted effects ------------------------------------------------------
b1 <- ggplot(dat9, aes(age, happy)) +
  geom_smooth(span = 0.4, formula = y ~ s(x, bs = "cs")) + 
  labs(x = '\nAge in years', y = 'Average self-reported happiness\n',
       title =  'A. Age', 
       subtitle =  '',
       caption = '') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
 
b1

b2 <- ggplot(dat9, aes(income, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nIncome decile', y = 'Average self-reported happiness\n',
       title =  'B. Income', 
       subtitle =  '',
       caption = '') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
b2

b12 <- b1 + b2 + plot_annotation(
  title =  'Unadjusted effects on happiness', 
  subtitle =  '',
  caption = 'Data: European Social Survey Round 9') & 
  my_theme_2()   +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
b12
ggsave(b12, file = './figures/unadjsted age income.png', width = 12, height = 9)

# Figure A8: Unadjusted effects with equivalized incomes ------------------------------------------------------
b2eq <- ggplot(dat9, aes(income.cor, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nIncome decile (equivalised)', y = 'Average self-reported happiness\n',
       title =  'C. Equivalized income', 
       subtitle =  '',
       caption = '') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
b2eq

b12eq <- b2 + b2eq + plot_annotation(
  title =  'Unadjusted effects on happiness', 
  subtitle =  '',
  caption = 'Data: European Social Survey Round 9') & 
  my_theme_2()   +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
b12eq
ggsave(b12eq, file = './figures/unadjsted age income_equivalized.png', width = 12, height = 9)

# Figure A4: Unadjusted effects per country ------------------------------------------------------

b1c <- b1 + facet_wrap(vars(as.factor(country)), ncol=5)
b2c <- b2 + facet_wrap(vars(as.factor(country)), ncol=5)
b1c
b2c

b12c <- b1c + b2c + plot_annotation(
  title =  'Unadjusted effects on happiness, per country', 
  subtitle =  '',
  caption = 'Data: European Social Survey Round 9') & 
  my_theme_2()   +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
b12c
ggsave(b12c, file = './figures/unadjsted age income country.png', width = 12, height = 9)

# Figure 2: Age on happiness per income ------------------------------------------------------
p1 <- ggplot(dat9, aes(age, happy)) +
  geom_smooth(method = 'gam', formula = y ~ s(x, bs = "cs")) + 
  labs(x = '\nAge in years', y = 'Average self-reported happiness\n',
       title =  'Effect of age on happiness for different income deciles', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.f)))
p1
ggsave(p1, file = './figures/age per income.png', width = 12, height = 9)

# Figure A9: Age on happiness per equivalized income ------------------------------------------------------
p1eq <- ggplot(dat9, aes(age, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nAge in years', y = 'Average self-reported happiness\n',
       title =  'Effect of age on happiness for different equivalized income deciles', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.cor)))
p1eq
ggsave(p1eq, file = './figures/age per income_eq.png', width = 12, height = 9)

# Figure A2: Age on life satisfaction per income ------------------------------------------------------
l1 <- ggplot(dat9, aes(age, life.satisfaction)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nAge in years', y = 'Average self-reported life satisfaction\n',
       title =  'Effect of age on life satisfaction for different income deciles', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.f)))
l1
ggsave(l1, file = './figures/lifesat age per income.png', width = 12, height = 9)

# Figure 3: Income on happiness per age group ------------------------------------------------------
p2 <- ggplot(dat9[!is.na(dat9$age.cat),], aes(income, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nIncome decile', y = 'Average self-reported happiness\n',
       title =  'Effect of income on happiness for different age groups', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  scale_x_continuous(limits=c(1,10), breaks=seq(2,10,2), labels=seq(2,10,2)) + 
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(age.cat)))
p2
ggsave(p2, file = './figures/income per age.png', width = 12, height = 9)

# Figure A10: Equivalized income on happiness per age group ------------------------------------------------------
p2eq <- ggplot(dat9[!is.na(dat9$age.cat),], aes(income.cor, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nEquivalized income decile', y = 'Average self-reported happiness\n',
       title =  'Effect of equivalized income on happiness for different age groups', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  scale_x_continuous(limits=c(1,10), breaks=seq(2,10,2), labels=seq(2,10,2)) + 
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(age.cat)))
p2eq
ggsave(p2eq, file = './figures/income_eq per age.png', width = 12, height = 9)

# Figure A3: Income on life satisfaction per age group ------------------------------------------------------
l2 <- ggplot(dat9[!is.na(dat9$age.cat),], aes(income, life.satisfaction)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nIncome decile', y = 'Average self-reported life satisfaction\n',
       title =  'Effect of income on life satisfaction for different age groups', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  scale_x_continuous(limits=c(1,10), breaks=seq(2,10,2), labels=seq(2,10,2)) + 
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(age.cat)))
l2
ggsave(l2, file = './figures/lifesat income per age.png', width = 12, height = 9)

# Figure 7 (left): Age on happiness per grouped income ------------------------------------------------------
p1.3 <- ggplot(dat9[!is.na(dat9$income.cat3),], aes(age, happy)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nAge in years', y = 'Average self-reported happiness\n',
       title =  'A. Unadjusted', 
       subtitle =  '') +
       #caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.cat3)))
p1.3
ggsave(p1.3, file = './figures/age per 3 income.png', width = 12, height = 9)

# Figure 5: Age on happiness per income per country ------------------------------------------------------
p3 <- ggplot(dat9[!is.na(dat9$income.cat2),], aes(age, happy, group=income.cat2, color=income.cat2)) +
  geom_smooth(span = 0.9, method = 'gam') + 
  labs(x = '\nAge in years', y = 'Average self-reported happiness\n',
       title =  'Effect of age on happiness for different income deciles', 
       subtitle =  'Countries are ordered by the average happiness of their population\n',
       caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2), legend.position='none') +
  facet_wrap(vars(as.factor(country)), ncol=5)

p3
ggsave(p3, file = './figures/age per income per country 2.png', width = 12, height = 12)

# End of part 2 of 6