###### This file replicates the analysis of happiness, age and income published in 
###### Toshkov (2021) 'The Relationship Between Age and Happiness Varies by Income', Journal of Happiness Studies
###### Part 5 of 6 (Statistical models). Last updated 1 September 2021

# Libraries and functions -------------------------------------------------
library(sjPlot)
library(mgcv)
source ('ggplot2 graphical settings.R')

# Subset variables --------------------------------------------------------
dat.s <- dat9 %>% select (happy, age, age.cat, income, income.f, income.cat3, country, feel.unhealthy, sex, edu, empl, married, lives.alone,
                          children, relig) %>% na.omit()
dat.s$age.sq = dat.s$age ^ 2 / 100

# Statistical models 1, 2, 3, and gam ----------------------------------------------
summary(msa1 <- lm(happy ~ age + age.sq + income + country + feel.unhealthy + sex  + edu  + empl  + married  +
                     lives.alone  + children  + relig, data=dat.s))

summary(msa2 <- lm(happy ~ age + age.sq + income + country + feel.unhealthy * income + sex * income + edu * income + empl * income + married * income +
                     lives.alone * income + children * income + relig * income, data=dat.s))

summary(msa3 <- lm(happy ~ country + feel.unhealthy + sex  + edu  + empl  + married  +
                     lives.alone  + children  + relig, data=dat.s))

tab_model(msa1, msa2, msa3, show.ci=FALSE, show.se=TRUE, digits=2, digits.p=2, digits.re=2, 
          string.se='SE', string.p='p', string.est = 'Coef.' , file = './tables/models 1 to 3 ols .html')

# GAM models --------------------------------------------------------------
summary(msgam <- mgcv::gam(happy ~ s(age) + income + country + feel.unhealthy * income + sex * income + edu * income + empl * income + married * income +
                             lives.alone * income + children * income + relig * income, data=dat.s))
summary(msgam2 <- mgcv::gam(happy ~ s(age) + s(income) + country + feel.unhealthy + sex + edu + empl + married +
                              lives.alone  + children  + relig, data=dat.s))

summary(msgam3 <- mgcv::gam(happy ~ s(age) + s(income) + ti (age, income), data=dat.s))

summary(msgam4 <- mgcv::gam (happy ~s(age) + s(income) + ti (age, income) + country + feel.unhealthy  + sex  + edu + empl  + married  +
                                lives.alone + children  + relig , data=dat.s))

plot(msgam)
layout(matrix(c(1,3,2,3),nrow=2))
plot(msgam2, scheme=1)

summary(msgam3 <- mgcv::gam(happy ~ s(age, by = income.cat), data=dat.s))
plot(msgam3)

plot(msgam4, scheme = 1)

# Plots with the residuals --------------------------------------------------------
dat.s$happy.resid <- residuals(msa3)

# Per income decile
r1 <- ggplot(dat.s, aes(age, happy.resid)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nAge in years', y = 'Residuals from models of happiness\n',
       title =  'Effect of age on residual happiness for different income deciles', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.f)))
r1
ggsave(r1, file = './figures/resid age per income.png', width = 12, height = 9)

# Per income category
r1.3 <- ggplot(dat.s, aes(age, happy.resid)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nAge in years', y = 'Residuals from models of happiness\n',
       title =  'B. Adjusted', 
       subtitle =  '') +
       #caption = 'Data: European Social Survey Round 9') +
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(income.cat3)))
r1.3
ggsave(r1.3, file = './figures/resid age per income 2.png', width = 12, height = 9)

# Combine with unadjusted figure
pr13 <- p1.3 + r1.3 + plot_annotation(
  title =  'Effect of age on happiness for different grouped income deciles', 
  subtitle =  '',
  caption = 'Data: European Social Survey Round 9') & 
  my_theme_2()   +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) 
pr13
ggsave(pr13, file = './figures/adjsted unadjusted age income.png', width = 12, height = 9)

# Per grouped age category
r2 <- ggplot(dat.s2, aes(income, happy.resid)) +
  geom_smooth(span = 0.4) + 
  labs(x = '\nIncome decile', y = 'Residuals from models of happiness\n',
       title =  'Effect of income on residual happiness for different age groups', 
       subtitle =  '',
       caption = 'Data: European Social Survey Round 9') +
  scale_x_continuous(limits=c(1,10), breaks=seq(2,10,2), labels=seq(2,10,2)) + 
  my_theme_2() +
  theme(panel.grid.minor = element_line(colour="lightgrey", size=0.2)) +
  facet_wrap(vars(as.factor(age.cat)))
r2
ggsave(r2, file = './figures/resid income per age.png', width = 12, height = 9)

# The end Part 5 of 6