###### This file replicates the analysis of happiness, age and income published in 
###### Toshkov (2021) 'The Relationship Between Age and Happiness Varies by Income', Journal of Happiness Studies
###### Part 6 of 6 (Colored, animated and interactive plots for the Rmardown file). Last updated 1 September 2021

# Libraries and functions -------------------------------------------------
library(rgl)
library(plot3D)
library(magick)
library(plotly)

# Data files (see '03 2d £D figures Wave 9.R' for the preparation of the data) -------------------------------------------------
load (file = './data/3d-data.Rdata')

load (file = './data/3d-elevation-data.Rdata')
u1<-unique(elevation.fit$x)
u2<-unique(elevation.fit$y)

# 3D density plot, version 1 in black and white -------------------------------------------------
par(mfrow = c(1, 1), mar = c(0, 0, 0, 0))
persp3D(z = temp.data, theta = 45, phi = 10, facets = T, curtain = TRUE, 
        shade=0.6, col = ramp.col(c("white", "black")), border = "grey", colkey = FALSE, xlab="Age (scaled)", ylab="Income (scaled)", zlab="Happiness")

# 3D density plot, version 2 in color -------------------------------------------------
par(mfrow = c(1, 1), mar = c(0, 0, 0, 0))
persp3D(z = temp.data, theta = 45, phi = 15, facets = T, curtain = TRUE, 
        shade=0.1, colkey = FALSE, xlab="Age (scaled)", ylab="Income (scaled)", zlab="Happiness", box=T, bty='b2',ticktype = "detailed")

# 3D density plot, version 3 ribbons in color -------------------------------------------------
par(mfrow = c(1, 1), mar = c(0, 0, 0, 0))
ribbon3D(z = temp.data, theta = 45, phi = 15, facets = T, curtain = TRUE, 
        shade=0.1, colkey = FALSE, xlab="Age (scaled)", ylab="Income (scaled)", zlab="Happiness", box=T, bty='b2',ticktype = "detailed")

### Prepare the gif -------------------------------------------------
# Number of frames for a gif
n_frames <- 180

# frame transition variables
thetavalues <- -45 + 90 * cos(seq(0, 2*pi, length.out = n_frames))

# generate .png frame images
img_frames <- paste0("./figures/gif/3Dgif", seq_len(n_frames), ".png")
for (i in seq_len(n_frames)) {
  message(paste(" - image", i, "of", n_frames))

  png(img_frames[i], width=900, height=700, res=96)
  persp3D(z = temp.data, theta = thetavalues[i], phi = 15, facets = T, curtain = TRUE, 
          shade=0.1, colkey = FALSE, xlab="Age (scaled)", ylab="Income (scaled)", zlab="Happiness", box=T, bty='b2',ticktype = "detailed")
  dev.off()
}

# build gif
magick::image_write_gif(magick::image_read(img_frames), 
                        path = "./figures/gif/happiness3D.gif", 
                        delay = 12/n_frames)


# Prepare interactive version with plotly  -------------------------------------------------
#with the plotly library
plot_ly(y=15:90, x=seq(1,10, by=0.12), z=temp.data2) %>%
  layout(
    title = "Happiness as a function of age and income, ESS Wave 9, 2018",
    scene = list(
      yaxis = list(title = "Age"),
      xaxis = list(title = "Income decile"),
      zaxis = list(title = "Happiness")
    )) %>% add_surface(contours = list(
      z = list(
        show=TRUE,
        usecolormap=TRUE,
        highlightcolor="#ff0000",
        project=list(z=TRUE)
      )
    ))

